Groups | Search | Server Info | Keyboard shortcuts | Login | Register [http] [https] [nntp] [nntps]


Groups > linux.kernel > #1620794

[PATCH] mfd: omap-usb-tll: Fix inverted bit use for USB TLL mode

From Tony Lindgren <tony@atomide.com>
Newsgroups linux.kernel
Subject [PATCH] mfd: omap-usb-tll: Fix inverted bit use for USB TLL mode
Date 2017-04-11 02:20 +0200
Message-ID <tuRHj-81J-1@gated-at.bofh.it> (permalink)
Organization linux.* mail to news gateway

Show all headers | View raw


Commit 16fa3dc75c22 ("mfd: omap-usb-tll: HOST TLL platform driver")
added support for USB TLL, but uses OMAP_TLL_CHANNEL_CONF_ULPINOBITSTUFF
bit the wrong way. The comments in the code are mostly correct, but the
inverted use of OMAP_TLL_CHANNEL_CONF_ULPINOBITSTUFF causes the register
to be enabled instead of disabled like the comments say. And the
idle mode should be only disabled for UTMIAUTOIDLE while ULPIAUTOIDLE
can be enabled.

This matches the TLL_CHANNEL_CONF_i register configuration for ehci-tll
in the Motorola Linux kernel tree for Wrigley 3G LTE modem on droid 4.
Without this patch the modem can only be pinged few times before it
stops responding. Also lsub -v output shows errors without this patch.

Fixes: 16fa3dc75c22 ("mfd: omap-usb-tll: HOST TLL platform driver")
Cc: Felipe Balbi <felipe.balbi@linux.intel.com>
Cc: Keshava Munegowda <keshava_mgowda@ti.com>
Cc: Marcel Partap <mpartap@gmx.net>
Cc: Michael Scott <michael.scott@linaro.org>
Cc: Roger Quadros <rogerq@ti.com>
Cc: Sebastian Reichel <sre@kernel.org>
Signed-off-by: Tony Lindgren <tony@atomide.com>
---
 drivers/mfd/omap-usb-tll.c | 11 ++++++-----
 1 file changed, 6 insertions(+), 5 deletions(-)

diff --git a/drivers/mfd/omap-usb-tll.c b/drivers/mfd/omap-usb-tll.c
--- a/drivers/mfd/omap-usb-tll.c
+++ b/drivers/mfd/omap-usb-tll.c
@@ -373,12 +373,13 @@ int omap_tll_init(struct usbhs_omap_platform_data *pdata)
 			} else if (pdata->port_mode[i] ==
 					OMAP_EHCI_PORT_MODE_TLL) {
 				/*
 				 * Disable AutoIdle, BitStuffing
 				 * and use SDR Mode
 				 */
-				reg &= ~(OMAP_TLL_CHANNEL_CONF_UTMIAUTOIDLE
-					| OMAP_TLL_CHANNEL_CONF_ULPINOBITSTUFF
-					| OMAP_TLL_CHANNEL_CONF_ULPIDDRMODE);
+				reg &= ~(OMAP_TLL_CHANNEL_CONF_UTMIAUTOIDLE |
+					 OMAP_TLL_CHANNEL_CONF_ULPIDDRMODE);
+				reg |= OMAP_TLL_CHANNEL_CONF_ULPINOBITSTUFF;
+				reg |= OMAP_TLL_CHANNEL_CONF_ULPI_ULPIAUTOIDLE;
 			} else if (pdata->port_mode[i] ==
 					OMAP_EHCI_PORT_MODE_HSIC) {
 				/*
@@ -373,12 +373,13 @@ int omap_tll_init(struct usbhs_omap_platform_data *pdata)
 					OMAP_EHCI_PORT_MODE_TLL) {
 				/*
-				 * Disable AutoIdle, BitStuffing
-				 * and use SDR Mode
+				 * Disable UTMI AutoIdle, BitStuffing
+				 * and use SDR Mode. Enable ULPI AutoIdle.
 				 */
-- 
2.12.2

Back to linux.kernel | Previous | NextNext in thread | Find similar | Unroll thread


Thread

[PATCH] mfd: omap-usb-tll: Fix inverted bit use for USB TLL mode Tony Lindgren <tony@atomide.com> - 2017-04-11 02:20 +0200
  Re: [PATCH] mfd: omap-usb-tll: Fix inverted bit use for USB TLL mode Roger Quadros <rogerq@ti.com> - 2017-04-11 09:40 +0200
    Re: [PATCH] mfd: omap-usb-tll: Fix inverted bit use for USB TLL mode Tony Lindgren <tony@atomide.com> - 2017-04-11 17:30 +0200

csiph-web